@@ -3,7 +3,7 @@ import os
 
 VB_MEDIA_UTILS_PATH = os.path.abspath(__file__)
 VB_MEDIA_UTILS_DIR = os.path.abspath(os.path.dirname(__file__));
-MEDIAFILES_DIR = os.path.join(VB_MEDIA_UTILS_DIR, '_assets'+os.sep)
+MEDIAFILES_DIR = os.path.join(VB_MEDIA_UTILS_DIR, 'assets'+os.sep)
 
 AUDIO_FILES_DIR = os.path.join(MEDIAFILES_DIR, 'audio'+os.sep);
 AUDIO_FILES = [];
@@ -41,4 +41,4 @@ def GetTestImagePath(filename=None):
     return IMAGE_FILE_PATHS[filename];
 
 def GetVBMarkPath():
-    return IMAGE_FILE_PATHS["VisBeatWatermark.png"];
\ No newline at end of file
+    return IMAGE_FILE_PATHS["VisBeatWatermark.png"];
